/**
 * Copyright (C) 2019-2021 Carl Kittelberger <icedream@icedream.pw>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import { IconProp } from '@fortawesome/fontawesome-svg-core';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
import React from 'react';
import { Button } from 'react-bootstrap';
import { getDownloadURL } from 'util/api';
import { FormattedMessage } from './localization';

export default function DownloadButton({
  icon,
  id,
  fileName,
}: {
  icon?: IconProp,
  id: string,
  fileName: string
}) {
  return (
    <Button variant="success" href={getDownloadURL(id, fileName)}>
      <FontAwesomeIcon icon={icon} className="mr-2" />
      <FormattedMessage
        id="DownloadButton.download"
        defaultMessage="Download"
        description="Text of the download button"
      />
    </Button>
  );
}

DownloadButton.defaultProps = {
  icon: 'download',
};
